import logging
import sys


class LoggingFactory:
    def __init__(self, name, loglevel=logging.DEBUG, logfile=None, stdout=False):
        self.name = name
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        _logger = logging.getLogger(self.name)
        _logger.setLevel(level=loglevel)

        file_logger = logfile and logging.FileHandler(logfile)
        stdout_logger = stdout and logging.StreamHandler(sys.stdout)

        stdout_logger and stdout_logger.setLevel(loglevel)
        stdout_logger and stdout_logger.setFormatter(formatter)
        stdout_logger and _logger.addHandler(stdout_logger)

        file_logger and file_logger.setLevel(loglevel)
        file_logger and file_logger.setFormatter(formatter)
        file_logger and _logger.addHandler(file_logger)

    @property
    def logger(self):
        return logging.getLogger(self.name)


logger = LoggingFactory('sakura', stdout=True).logger



import unittest


class TestMysql(unittest.TestCase):

    def setUp(self):
        super().setUp()
        db = {
            'host': '127.0.0.1',
            'user': 'root',
            'password': 'password',
            'db': 'arbhac'
        }
        from sakura.mysql import connect
        self.sakura = connect(**db)

    def test_get_model(self):
        Test = self.sakura.getModel('test')
        print(Test.__mappings__)
        self.assertEqual(1, 1)


class TestSqlUtil(unittest.TestCase):
    def test_field_value(self):
        from sakura.util import SqlUtil
        _field_value = {
            'a': 1,
            'b': 2,
            'c': 'c'
        }
        field_value, args = SqlUtil.get_field_value(_field_value)
        self.assertEqual(field_value, '`a` = %s, `b` = %s, `c` = %s')
        self.assertEqual(args, [1, 2, 'c'])


if __name__ == '__main__':
    unittest.main()



from setuptools import setup

setup(
    name='SakuraMysql',
    version='0.1.8',
    description=(
        'mysql orm'
    ),
    long_description='mysql orm',
    author='SVz',
    author_email='903943711@qq.com',
    maintainer='SVz',
    maintainer_email='<903943711@qq.com',
    license='MIT License',
    packages=['sakura', 'tests'],
    package_dir={
        'sakura': 'sakura',
        'tests': 'tests',
    },
    install_requires=['pymysql'],
    python_requires='>=3.6',
    platforms=["all"],
    url='https://github.com/SVz777/Sakura',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
